@@ -7,7 +7,7 @@ __all__ = ["__author__",
            "coinToBinary"]
 
 __author__ = "Diego Ramirez"
-__version__ = "3.2"
+__version__ = "0.0.4"
 
 
 import random
@@ -19,35 +19,47 @@ class InitError(TypeError):
 
 
 class Aleatoryous():
+    "New since 0.0.4: Some variables deleted or recycled"
     tot = 0
-    cache = ""
-    mode = ""
+    #__cache = ["Coin", "Dice", "Roulette"]
+    __mode = ""
     parser = ""
     lst = []
-    methods = ["__init__", "__len__", "__dir__", "refresh", "single", "first_5", "first_10", "first_50", "first_100", "first"]
+    __methods = ["__init__",
+                 "__len__",
+                 "__dir__",
+                 "refresh",
+                 "single",
+                 "first_5",
+                 "first_10",
+                 "first_50",
+                 "first_100",
+                 "first_given",
+                 "getmode",
+                 "changemode"]
     dict = {}
-    it = None
+    #it = None
 
     def __init__(self, mode="aleatory.coin", extras=None):
         if mode == "aleatory.coin":
-            self.mode = "Coin"
+            self.__mode = "Coin"
         elif mode == "aleatory.dice":
-            self.mode = "Dice"
+            self.__mode = "Dice"
         elif mode == "aleatory.roulette":
-            self.mode = "Roulette"
+            self.__mode = "Roulette"
             if extras is not None:
                 self.parser = extras
+            elif not isinstance(self.parser, "list"):
+                raise InitError(IE.parameter_bug())
             else:
-                raise InitError(IE.parameter_bug())
-            if not isinstance(self.parser, "list"):
-                raise InitError(IE.parameter_bug())
+                pass
             for i in range(len(self.parser)):
                 self.it = i + 1
                 self.dict[self.parser[i]] = self.it
         else:
             raise InitError(IE.modal_bug())
-        self.cache = ""
-        self.type = mode
+        #self.cache = ""
+        self.__modetye = mode
         self.parser = ""
 
 
@@ -57,7 +69,7 @@ class Aleatoryous():
 
 
     def single(self):
-        if self.mode == "Coin":
+        if self.__mode == "Coin":
             self.tot = random.randint(0, 1)
             if self.tot == 1:
                 return "Head"
@@ -66,11 +78,11 @@ class Aleatoryous():
             else:
                 return None
 
-        elif self.mode == "Dice":
+        elif self.__mode == "Dice":
             self.tot = random.randint(1, 6)
             return self.tot
 
-        elif self.mode == "Roulette":
+        elif self.__mode == "Roulette":
             self.tot = random.randint(1, len(self.dict))
             for k, v in self.dict.items():
                 if v == self.tot:
@@ -81,7 +93,7 @@ class Aleatoryous():
 
     def first_5_basic(self):
         for time in [1, 2, 3, 4, 5]:
-            if self.mode == "Coin":
+            if self.__mode == "Coin":
                 self.tot = random.randint(0, 1)
                 if self.tot == 1:
                     self.lst.append("Head")
@@ -89,10 +101,10 @@ class Aleatoryous():
                     self.lst.append("Tails")
                 else:
                     self.lst.append(None)
-            elif self.mode == "Dice":
+            elif self.__mode == "Dice":
                 self.tot = random.randint(1, 6)
                 self.lst.append(self.tot)
-            elif self.mode == "Roulette":
+            elif self.__mode == "Roulette":
                 self.tot = random.randint(1, len(self.dict))
                 for k, v in self.dict.items():
                     if v == self.tot:
@@ -138,18 +150,34 @@ class Aleatoryous():
             self.first_5_basic()
         return self.lst
 
+    def getmode(self):
+        "New since 0.0.3: get the private mode."
+        self.refresh()
+        return self.__modetype
+
+    def changemode(self, mode, extras=None):
+        "New since 0.0.3: restart the object with a new mode."
+        self.__init__(mode, extras)
+
     # Some built-in functions
     def __len__(self):
-        return 3
+        return 3  # The 3 modes
     def __dir__(self):
-        return self.methods
+        return self.__methods
     def __str__(self):
-        return "Aleatoryous" + " " + self.mode
+        return "Aleatoryous" + " " + self.__modetype
+
 
 def coinToBinary(res):
-    if res == "Head":
+    if res.strip().lower() == "head":
         return 1
-    elif res == "Tails":
+    elif res.strip().lower() == "tails":
         return 0
     else:
         return None
+
+if __name__ == '__main__':
+    # Try the new function Aleatoryous.changemode() of version 0.0.3
+    _i = Aleatoryous("aleatory.dice")
+    _i.changemode("aleatory.coin")
+    print("Done")
